module.exports = defineTest({
	description: 'detects side-effects in template literals and tagged template expressions',
	options: { output: { name: 'myBundle' } }
});
